==> kpogre-1.2.7.tar.gz: kpogre-1.2.7/kpogre/DbObjects/kpgdomainsfolder.cpp <==
//
// C++ Implementation: kpgdomainsfolder
//
// Description: 
//
//
// Author: Lumir Vanek <lvanek@users.sourceforge.net>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//
#include "kpgdomainsfolder.h"

#include <qtable.h>

#include <kdebug.h>
#include <kmessagebox.h>
#include <klocale.h>

#include "kpgconnection.h"
#include "kpgschema.h"
#include "kpgdomain.h"
#include "../PropertyPages/kpgpropertypage.h"
#include "../kpgsqldialog.h"

KPGDomainsFolder::KPGDomainsFolder(KPGSchema *parent, pqxx::oid oidNameSpace)
 : KPGItemsFolder(parent, i18n("Domains"))
{
	m_oidNameSpace = oidNameSpace;
}


KPGDomainsFolder::~KPGDomainsFolder()
{
}

bool KPGDomainsFolder::refresh(pqxx::work &pqxxXaction)
{
  // delete all child items 
  while (QListViewItem * pItem = firstChild())
    delete pItem;

	// obtain list of domains
  QString strQuery("SELECT d.oid, d.typname as domname, description, b.oid AS basetypeoid, b.typname as basetype, d.typlen, d.typnotnull, d.typdefault, d.typndims, d.typdelim, pg_get_userbyid(d.typowner) as owner ");
	strQuery.append("FROM pg_type d ");
	strQuery.append("JOIN pg_type b ON b.oid = CASE WHEN d.typndims > 0 THEN d.typelem ELSE d.typbasetype END ");
	strQuery.append("LEFT OUTER JOIN pg_description des ON des.objoid=d.oid ");
	strQuery.append("WHERE d.typtype = 'd' ");
	strQuery.append("AND d.typnamespace = " + QString("%1").arg(m_oidNameSpace) + " ");
	strQuery.append("ORDER BY d.typname");
			
  try
  {
    m_pqxxResultDomains = pqxxXaction.Exec(strQuery.latin1());

		KPGDomain *pgDomain = 0;
		
    for (result::size_type i = 0; i != m_pqxxResultDomains.size(); ++i)
    {
			pqxx::oid oid;
			m_pqxxResultDomains[i][0].to(oid);
		
			if(pgDomain == 0)
      	pgDomain = new KPGDomain(this, m_pqxxResultDomains[i]["domname"].c_str(), oid);
			else
				pgDomain = new KPGDomain(this, pgDomain, m_pqxxResultDomains[i]["domname"].c_str(), oid);
		
			pqxx::oid oidBaseType = 0;
			int iTypLen;
			bool bNotNull;
			int iTypNDims;

			m_pqxxResultDomains[i]["basetypeoid"].to(oidBaseType);
			m_pqxxResultDomains[i]["typlen"].to(iTypLen);
			m_pqxxResultDomains[i]["typnotnull"].to(bNotNull);
			m_pqxxResultDomains[i]["typndims"].to(iTypNDims);
						
			pgDomain->setProperties(
				m_pqxxResultDomains[i]["description"].c_str(),
				oidBaseType, 
				m_pqxxResultDomains[i]["basetype"].c_str(),
				iTypLen,
				bNotNull,
				m_pqxxResultDomains[i]["typdefault"].c_str(),
				iTypNDims,
				m_pqxxResultDomains[i]["typdelim"].c_str(),
				m_pqxxResultDomains[i]["owner"].c_str()
				);
        
      pgDomain->refreshConstraints(pqxxXaction); 
    }
  }
  catch (const std::exception &e)
  {
    kdError() << e.what() << endl;
    KPGSqlDialog dlg(0, strQuery, e.what());
		dlg.exec();
    return false;
  } 
  
  return true;
}

void KPGDomainsFolder::displayProperties(QWidget *widgetProperies)
{
	KPGPropertyPage *pPropertyPage = static_cast <KPGPropertyPage *> (widgetProperies);
  pPropertyPage->setLabelText(i18n("Domains &list:"));
	
	//----------------------------------------------------------------------------
	//Display domains list
		
  QTable *pTableDomains = pPropertyPage->m_pTableItems;
  
  // fill properties table with result data
	int nTableCols = fillPropertiesTable(m_pqxxResultDomains, pTableDomains);

  // field names
  QHeader* hHeader = pTableDomains->horizontalHeader();

  int nCol = 0;
	hHeader->setLabel(nCol++, i18n("Name"));
  hHeader->setLabel(nCol++, i18n("Description"));
	hHeader->setLabel(nCol++, i18n("Base type"));
  hHeader->setLabel(nCol++, i18n("Type length"));
	hHeader->setLabel(nCol++, i18n("Not null"));
  hHeader->setLabel(nCol++, i18n("Default value"));
  hHeader->setLabel(nCol++, i18n("Dimensions"));
  hHeader->setLabel(nCol++, i18n("Array delimiter"));
	hHeader->setLabel(nCol++, i18n("Owner"));
	

  for(int nCol = 0; nCol < nTableCols; nCol++)
  {
    pTableDomains->adjustColumn(nCol);
  }
}

==> kpogre-1.5.2.tar.gz: kpogre-1.5.2/kpogre/DbObjects/kpgdomainsfolder.cpp <==
//
// C++ Implementation: kpgdomainsfolder
//
// Description: 
//
//
// Author: Lumir Vanek <lvanek@users.sourceforge.net>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//
#include "kpgdomainsfolder.h"

#include <qtable.h>

#include <kdebug.h>
#include <kmessagebox.h>
#include <klocale.h>

#include "kpgconnection.h"
#include "kpgschema.h"
#include "kpgdomain.h"
#include "../PropertyPages/kpgpropertypage.h"
#include "../kpgsqldialog.h"

KPGDomainsFolder::KPGDomainsFolder(KPGSchema *parent, pqxx::oid oidNameSpace)
 : KPGItemsFolder(parent, i18n("Domains"))
{
	m_oidNameSpace = oidNameSpace;
}


KPGDomainsFolder::~KPGDomainsFolder()
{
}

bool KPGDomainsFolder::refresh(pqxx::work &pqxxXaction)
{
  // delete all child items 
  while (QListViewItem * pItem = firstChild())
    delete pItem;

	// obtain list of domains
  QString strQuery("SELECT d.oid, d.typname as domname, description, b.oid AS basetypeoid, b.typname as basetype, d.typlen, d.typnotnull, d.typdefault, d.typndims, d.typdelim, pg_get_userbyid(d.typowner) as owner ");
	strQuery.append("FROM pg_catalog.pg_type d ");
	strQuery.append("JOIN pg_catalog.pg_type b ON b.oid = CASE WHEN d.typndims > 0 THEN d.typelem ELSE d.typbasetype END ");
	strQuery.append("LEFT OUTER JOIN pg_catalog.pg_description des ON des.objoid=d.oid ");
	strQuery.append("WHERE d.typtype = 'd' ");
	strQuery.append("AND d.typnamespace = " + QString("%1").arg(m_oidNameSpace) + " ");
	strQuery.append("ORDER BY d.typname");
			
  try
  {
    m_pqxxResultDomains = pqxxXaction.Exec(strQuery.latin1());

		KPGDomain *pgDomain = 0;
		
    for (result::size_type i = 0; i != m_pqxxResultDomains.size(); ++i)
    {
			pqxx::oid oid;
			m_pqxxResultDomains[i][0].to(oid);
		
			if(pgDomain == 0)
      	pgDomain = new KPGDomain(this, m_pqxxResultDomains[i]["domname"].c_str(), oid);
			else
				pgDomain = new KPGDomain(this, pgDomain, m_pqxxResultDomains[i]["domname"].c_str(), oid);
		
			pqxx::oid oidBaseType = 0;
			int iTypLen;
			bool bNotNull;
			int iTypNDims;

			m_pqxxResultDomains[i]["basetypeoid"].to(oidBaseType);
			m_pqxxResultDomains[i]["typlen"].to(iTypLen);
			m_pqxxResultDomains[i]["typnotnull"].to(bNotNull);
			m_pqxxResultDomains[i]["typndims"].to(iTypNDims);
						
			pgDomain->setProperties(
				m_pqxxResultDomains[i]["description"].c_str(),
				oidBaseType, 
				m_pqxxResultDomains[i]["basetype"].c_str(),
				iTypLen,
				bNotNull,
				m_pqxxResultDomains[i]["typdefault"].c_str(),
				iTypNDims,
				m_pqxxResultDomains[i]["typdelim"].c_str(),
				m_pqxxResultDomains[i]["owner"].c_str()
				);
        
      pgDomain->refreshConstraints(pqxxXaction); 
    }
  }
  catch (const std::exception &e)
  {
    kdError() << e.what() << endl;
    KPGSqlDialog dlg(0, strQuery, e.what());
		dlg.exec();
    return false;
  } 
  
  return true;
}

void KPGDomainsFolder::displayProperties(QWidget *widgetProperies)
{
	if(widgetProperies == 0) return; // be defensive, user may close Properties window
	
	KPGPropertyPage *pPropertyPage = static_cast <KPGPropertyPage *> (widgetProperies);
  pPropertyPage->setLabelText(i18n("Domains &list:"));
	
	//----------------------------------------------------------------------------
	//Display domains list
		
  	QTable *pTableDomains = pPropertyPage->m_pTableItems;
  
  // fill properties table with result data
	int nTableCols = fillPropertiesTable(m_pqxxResultDomains, pTableDomains);

  // field names
  	QHeader* hHeader = pTableDomains->horizontalHeader();

  	int nCol = 0;
	hHeader->setLabel(nCol++, i18n("Name"));
  	hHeader->setLabel(nCol++, i18n("Description"));
	hHeader->setLabel(nCol++, i18n("Base type"));
  	hHeader->setLabel(nCol++, i18n("Type length"));
	hHeader->setLabel(nCol++, i18n("Not null"));
	hHeader->setLabel(nCol++, i18n("Default value"));
	hHeader->setLabel(nCol++, i18n("Dimensions"));
	hHeader->setLabel(nCol++, i18n("Array delimiter"));
	hHeader->setLabel(nCol++, i18n("Owner"));
	

  for(int nCol = 0; nCol < nTableCols; nCol++)
  {
    pTableDomains->adjustColumn(nCol);
  }
}
